
STATUS_OK = "Ok"

TOKEN_PROGRAM_ID = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA"

class cluster_endpoints:
    MAINNET_BETA = "https://api.mainnet-beta.solana.com"
    MAINNET_BETA_SERUM = "https://solana-api.projectserum.com"
    